@@ -9,8 +9,8 @@ from datazimmer.config_loading import RunConfig
 from datazimmer.get_runtime import get_runtime
 from datazimmer.naming import DEFAULT_ENV_NAME, MAIN_MODULE_NAME, TEMPLATE_REPO
 from datazimmer.tests.create_dogshow import dogshow_root
-from datazimmer.typer_commands import build_meta, cleanup
-from datazimmer.utils import cd_into, reset_meta_module
+from datazimmer.typer_commands import cleanup
+from datazimmer.utils import cd_into, gen_rmtree, reset_meta_module
 
 CORE_PY = dogshow_root / "minimal.py"
 
@@ -22,16 +22,16 @@ def pytest_addoption(parser):
 
 @pytest.fixture(scope="session")
 def empty_template():
-    with TemporaryDirectory() as tmpdir:
-        check_call(["git", "clone", TEMPLATE_REPO, tmpdir])
-        with cd_into(tmpdir):
-            check_call(["dvc", "remote", "add", "testrem", "/nothing"])
-            check_call(["dvc", "remote", "default", "testrem"])
-            Path(MAIN_MODULE_NAME, "core.py").write_text(CORE_PY.read_text())
-            build_meta()
-        yield tmpdir
-        with cd_into(tmpdir):
-            cleanup()
+    tmpdir = TemporaryDirectory().name
+    check_call(["git", "clone", TEMPLATE_REPO, tmpdir])
+    with cd_into(tmpdir):
+        check_call(["dvc", "remote", "add", "testrem", "/nothing"])
+        check_call(["dvc", "remote", "default", "testrem"])
+        Path(MAIN_MODULE_NAME, "core.py").write_text(CORE_PY.read_text())
+    yield tmpdir
+    with cd_into(tmpdir):
+        cleanup()
+    gen_rmtree(tmpdir)
 
 
 @pytest.fixture
